PdfFillPathCommand class

Inheritance

Constructors

PdfFillPathCommand(PdfPath path, PdfColor color, PdfFillRule rule, double alpha)
const

Properties

alpha double
final
color PdfColor
final
hashCode int
The hash code for this object.
no setterinherited
path PdfPath
final
rule PdfFillRule
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited