PdfMeshParser class

Decodes the bit-packed vertex/patch data of mesh shadings.

Constructors

PdfMeshParser({required Uint8List data, required int shadingType, required int bitsPerCoordinate, required int bitsPerComponent, required int bitsPerFlag, required List<double> decode, required int components, required int verticesPerRow, required PdfFunction? function, required PdfColor toColor(List<double>), required PdfMatrix transform})

Properties

bitsPerComponent int
final
bitsPerCoordinate int
final
bitsPerFlag int
final
components int
final
decode List<double>
final
function PdfFunction?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadingType int
final
toColor PdfColor Function(List<double>)
Maps the vertices' colour values, in the shading's own colour space, to sRGB - the shading's PdfColorSpace.toSrgb, so Separation/DeviceN/ ICCBased/CIE mesh shadings convert the same way axial and radial ones do.
final
transform PdfMatrix
final
verticesPerRow int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() PdfMesh?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited