PdfSetOverprintCommand class

Inheritance

Constructors

PdfSetOverprintCommand({required bool fill, required bool stroke, required int mode})
const

Properties

fill bool
final
hashCode int
The hash code for this object.
no setterinherited
mode int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stroke bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited