PdfStroke class

Stroke parameters, with width already scaled into page space.

Constructors

PdfStroke({double width = 1, int cap = 0, int join = 0, double miterLimit = 10, List<double> dashArray = const [], double dashPhase = 0})
const

Properties

cap int
0 = butt, 1 = round, 2 = projecting square (8.4.3.3).
final
dashArray List<double>
final
dashPhase double
final
hashCode int
The hash code for this object.
no setterinherited
join int
0 = miter, 1 = round, 2 = bevel (8.4.3.4).
final
miterLimit double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
final

Methods

copyWith({double? width, int? cap, int? join, double? miterLimit, List<double>? dashArray, double? dashPhase}) PdfStroke
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited