glyphs property
Real glyph outlines from the embedded font, when available. Devices should prefer these over substituted text rendering.
Implementation
final List<PdfGlyphPlacement>? glyphs;
Real glyph outlines from the embedded font, when available. Devices should prefer these over substituted text rendering.
final List<PdfGlyphPlacement>? glyphs;