FlatSubpath class

One flattened subpath: [x0,y0, x1,y1, ...]. points is Float64List-backed (unboxed indexing).

Constructors

FlatSubpath(Float64List points, {required bool closed})

Properties

closed bool
final
hashCode int
The hash code for this object.
no setterinherited
pointCount int
no setter
points Float64List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited