collisions property
Draws whose 32-bit content hash matched a stored entry with different content; rendered directly (correctness never rides on the hash).
Implementation
int collisions = 0;
Draws whose 32-bit content hash matched a stored entry with different content; rendered directly (correctness never rides on the hash).
int collisions = 0;