SlugBatchBuilder class

Accumulates one painter-order Slug window without any dart:ui objects.

Constructors

SlugBatchBuilder()

Properties

estimatedVExtent double
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
quadCount int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotCount int
no setter

Methods

addGlyph(PdfPath outline, SlugGlyphData data, PdfMatrix emToPage, double pxPerEmX, double pxPerEmY, int argb) → void
build([int flushOrdinal = 0]) SlugBatchData?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overlaps(double minX, double minY, double maxX, double maxY) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited