SlugBatchData class

One painter-order Slug batch in worker-transferable form.

Constructors

SlugBatchData(int flushOrdinal, List<SlugChunkData> chunks, Uint8List atlasPixels, int atlasWidth, int atlasHeight, int quadCount, double cellHeight)

Properties

atlasHeight int
final
atlasPixels Uint8List
final
atlasWidth int
final
cellHeight double
final
chunks List<SlugChunkData>
final
flushOrdinal int
The strip flush point immediately preceding this text run.
final
hashCode int
The hash code for this object.
no setterinherited
quadCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited