delegateSave abstract method
void
delegateSave()
Delegated state ops (no pixels; not flush points except clipPath and the group boundaries, which the base flushes before forwarding).
Implementation
void delegateSave();
Delegated state ops (no pixels; not flush points except clipPath and the group boundaries, which the base flushes before forwarding).
void delegateSave();