emitBatch abstract method

void emitBatch(
  1. int ordinal,
  2. StripBatchData? data
)

Called at every flush point with the strips binned since the previous one (data null when nothing was binned, or when binningEnabled is off). ordinal is the flush point's 0-based index.

Implementation

void emitBatch(int ordinal, StripBatchData? data);