stripsActive property

bool get stripsActive

Whether paint ops may take the strip path right now: normal blend and not directly inside a knockout group (knockout elements composite with BlendMode.src, which batched srcOver quads can't express).

Implementation

bool get stripsActive =>
    !delegateAll &&
    _blend == PdfBlendMode.normal &&
    (_groupKnockout.isEmpty || !_groupKnockout.last);