pageToDevice property
Page space -> device pixels, exactly as the consuming device will be constructed (the six coefficients round-trip bit-exactly).
Implementation
final PdfMatrix pageToDevice;
Page space -> device pixels, exactly as the consuming device will be constructed (the six coefficients round-trip bit-exactly).
final PdfMatrix pageToDevice;