emitBatch method

  1. @override
void emitBatch(
  1. int ordinal,
  2. StripBatchData? data
)
override

Called at every flush point with the strips binned since the previous one (data null when nothing was binned, or when binningEnabled is off). ordinal is the flush point's 0-based index.

Implementation

@override
void emitBatch(int ordinal, StripBatchData? data) {
  if (data != null) batches.add(data);
}