ContentStreamParser class
Parses a page content stream into a flat list of operations.
An inline image (BI ... ID ... EI) is surfaced as a single BI
operation whose operands are the image dictionary and the raw image data
as a CosString.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
Uint8List content) → List< ContentOperation>