PdfFieldContext class
One interactive form field, flattened for an agent.
Constructors
- PdfFieldContext({required String name, required String type, required String? value, required int pageIndex})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Fully qualified field name — the stable handle for setting a value.
final
- pageIndex → int
-
Page showing the field's first widget, or −1 when unplaced.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Field kind ('text', 'checkBox', 'comboBox', ...).
final
- value → String?
-
Current value, if any.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited