writesAll property
Separation /All (8.6.6.4): the tint is applied to every colorant the
device has, including spot colorants only the backdrop carries.
Implementation
final bool writesAll;
Separation /All (8.6.6.4): the tint is applied to every colorant the
device has, including spot colorants only the backdrop carries.
final bool writesAll;