PdfPath class
Constructors
-
PdfPath(List<
PdfPathSegment> segments) -
const
- PdfPath.packedFloat32(Uint8List verbs, Float32List coordinates, int segmentCount)
- Constructs the compact float32 path representation used by the render command decoder.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentCount → int
-
no setter
-
segments
→ List<
PdfPathSegment> -
The path as segment objects.
no setter
Methods
-
cursor(
) → PdfPathCursor - Opens a non-allocating sequential reader over this path.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited