mcid property
The marked-content id (/MCID) of the innermost tagged marked-content sequence enclosing this run, or null when the run is untagged. In a Tagged PDF this ties the run to a structure element (14.7).
Implementation
final int? mcid;
The marked-content id (/MCID) of the innermost tagged marked-content sequence enclosing this run, or null when the run is untagged. In a Tagged PDF this ties the run to a structure element (14.7).
final int? mcid;