Optional capability interface for devices that can consume a
PdfDrawTiledCellCommand natively instead of replaying its per-tile
expansion. The interpreter and replayCommands probe for it with is.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
drawTiledCell(
PdfDrawTiledCellCommand command) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited