DoubleBuilder class
Growable Float64List: unboxed accumulation for geometry in device pixels.
Constructors
- DoubleBuilder([int capacity = 256])
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- length ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- view → Float64List
-
A view of the filled prefix. Valid until the next add.
no setter
Methods
-
add2(
double a, double b) → void -
add6(
double a, double b, double c, double d, double e, double f) → void -
clear(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int i) → double -
operator []=(
int i, double v) → void