QuadCurve class
One quadratic Bezier segment in em space (y-up, origin on the
baseline): p0 = (x0,y0), control (cx,cy), p1 = (x1,y1).
Properties
- cx → double
-
final
- cy → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxX → double
-
no setter
- maxY → double
-
no setter
- minX → double
-
no setter
- minY → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x0 → double
-
final
- x1 → double
-
final
- y0 → double
-
final
- y1 → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited